@@ -328,7 +328,7 @@ setMethod("plot", signature(x="CovNARobust", y="missing"), function(x, y="missin
 
     panel.hist <- function(x, ...)
     {
-        usr <- par("usr"); on.exit(par(usr))
+        usr <- par("usr"); on.exit(par(usr=usr))
         par(usr = c(usr[1:2], 0, 1.5) )
         h <- hist(x, plot = FALSE)
         breaks <- h$breaks; nB <- length(breaks)
@@ -338,7 +338,7 @@ setMethod("plot", signature(x="CovNARobust", y="missing"), function(x, y="missin
 
     panel.hist.density <- function(x,...)
     {
-        usr <- par("usr"); on.exit(par(usr))
+        usr <- par("usr"); on.exit(par(usr=usr))
         par(usr = c(usr[1:2], 0, 1.5) )
 
         h <- hist(x, plot = FALSE)
@@ -347,7 +347,7 @@ setMethod("plot", signature(x="CovNARobust", y="missing"), function(x, y="missin
         rect(breaks[-nB], 0, breaks[-1], y, col=hcol)
 
         tryd <- try( d <- density(x, na.rm=TRUE, bw="nrd", adjust=1.2), silent=TRUE)
-        if(class(tryd) != "try-error")
+        if(is(tryd, "try-error"))
         {
             d$y <- d$y/max(d$y)
             lines(d, col=dcol)
@@ -358,7 +358,7 @@ setMethod("plot", signature(x="CovNARobust", y="missing"), function(x, y="missin
     {
         ix <- which.ij(x, y, getData(obj))
 
-        usr <- par("usr"); on.exit(par(usr))
+        usr <- par("usr"); on.exit(par(usr=usr))
         par(usr = c(0, 1, 0, 1))
 
         r <- cor(x, y, use="pairwise.complete.obs")
@@ -380,7 +380,7 @@ setMethod("plot", signature(x="CovNARobust", y="missing"), function(x, y="missin
     }
     panel.ellipse <- function(x, y, ...)
     {
-        usr <- par("usr"); on.exit(par(usr))
+        usr <- par("usr"); on.exit(par(usr=usr))
 
         ix <- which.ij(x, y, getData(obj))
 
