@@ -8,11 +8,15 @@
 
 /* .Fortran calls */
 extern void F77_NAME(emnint)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(fnanmcd)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(fnanmcd)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, 
+                              void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, 
+                              void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, 
+                              void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, 
+                              void *, void *);
 
 static const R_FortranMethodDef FortranEntries[] = {
     {"emnint",  (DL_FUNC) &F77_NAME(emnint),  11},
-    {"fnanmcd", (DL_FUNC) &F77_NAME(fnanmcd), 55},
+    {"fnanmcd", (DL_FUNC) &F77_NAME(fnanmcd), 42},
     {NULL, NULL, 0}
 };
 
